==> openshift-model-operator-6.3.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/KubeAPIServerListFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface KubeAPIServerListFluent<A extends KubeAPIServerListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,KubeAPIServer item);
  public A setToItems(Integer index,KubeAPIServer item);
  public A addToItems(io.fabric8.openshift.api.model.operator.v1.KubeAPIServer... items);
  public A addAllToItems(Collection<KubeAPIServer> items);
  public A removeFromItems(io.fabric8.openshift.api.model.operator.v1.KubeAPIServer... items);
  public A removeAllFromItems(Collection<KubeAPIServer> items);
  public A removeMatchingFromItems(Predicate<KubeAPIServerBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<KubeAPIServer> getItems();
  public List<KubeAPIServer> buildItems();
  public KubeAPIServer buildItem(Integer index);
  public KubeAPIServer buildFirstItem();
  public KubeAPIServer buildLastItem();
  public KubeAPIServer buildMatchingItem(Predicate<KubeAPIServerBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<KubeAPIServerBuilder> predicate);
  public A withItems(List<KubeAPIServer> items);
  public A withItems(io.fabric8.openshift.api.model.operator.v1.KubeAPIServer... items);
  public Boolean hasItems();
  public KubeAPIServerListFluent.ItemsNested<A> addNewItem();
  public KubeAPIServerListFluent.ItemsNested<A> addNewItemLike(KubeAPIServer item);
  public KubeAPIServerListFluent.ItemsNested<A> setNewItemLike(Integer index,KubeAPIServer item);
  public KubeAPIServerListFluent.ItemsNested<A> editItem(Integer index);
  public KubeAPIServerListFluent.ItemsNested<A> editFirstItem();
  public KubeAPIServerListFluent.ItemsNested<A> editLastItem();
  public KubeAPIServerListFluent.ItemsNested<A> editMatchingItem(Predicate<KubeAPIServerBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,KubeAPIServerFluent<KubeAPIServerListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> openshift-model-operator-6.7.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/KubeAPIServerListFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface KubeAPIServerListFluent<A extends KubeAPIServerListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,KubeAPIServer item);
  public A setToItems(int index,KubeAPIServer item);
  public A addToItems(io.fabric8.openshift.api.model.operator.v1.KubeAPIServer... items);
  public A addAllToItems(Collection<KubeAPIServer> items);
  public A removeFromItems(io.fabric8.openshift.api.model.operator.v1.KubeAPIServer... items);
  public A removeAllFromItems(Collection<KubeAPIServer> items);
  public A removeMatchingFromItems(Predicate<KubeAPIServerBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<KubeAPIServer> getItems();
  public List<KubeAPIServer> buildItems();
  public KubeAPIServer buildItem(int index);
  public KubeAPIServer buildFirstItem();
  public KubeAPIServer buildLastItem();
  public KubeAPIServer buildMatchingItem(Predicate<KubeAPIServerBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<KubeAPIServerBuilder> predicate);
  public A withItems(List<KubeAPIServer> items);
  public A withItems(io.fabric8.openshift.api.model.operator.v1.KubeAPIServer... items);
  public Boolean hasItems();
  public KubeAPIServerListFluent.ItemsNested<A> addNewItem();
  public KubeAPIServerListFluent.ItemsNested<A> addNewItemLike(KubeAPIServer item);
  public KubeAPIServerListFluent.ItemsNested<A> setNewItemLike(int index,KubeAPIServer item);
  public KubeAPIServerListFluent.ItemsNested<A> editItem(int index);
  public KubeAPIServerListFluent.ItemsNested<A> editFirstItem();
  public KubeAPIServerListFluent.ItemsNested<A> editLastItem();
  public KubeAPIServerListFluent.ItemsNested<A> editMatchingItem(Predicate<KubeAPIServerBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,KubeAPIServerFluent<KubeAPIServerListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
